#
# spec file for package ibus-table-chinese
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-table-chinese
Version:        1.8.12
Release:        1.4
Summary:        Various Chinese input method table for the IBus framework
License:        GPL-3.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/mike-fabian/ibus-table-chinese
Source:         https://github.com/mike-fabian/ibus-table-chinese/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ibus-table)
BuildArch:      noarch

%description
ibus-table-chinese provides the infrastructure for Chinese input methods.
Input tables themselves are in sub-packages.

%package array
Summary:        The "array" input methods for Chinese
Group:          System/I18n/Chinese
Provides:       ibus-table-array30 = %{version}-%{release}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-array30 < 1.3
%{ibus_table_requires}

%description array
Array input method is a character-structured input method, including:
array30: 27489 characters.
array30-big: 27489 characters + Unicode ExtB.

%package cangjie
Summary:        Cangjie based input methods
Group:          System/I18n/Chinese
Provides:       ibus-table-cangjie = %{version}-%{release}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-cangjie < 1.3
%{ibus_table_requires}

%description cangjie
Cangjie based input methods, including:
Cangjie3, Canjie5, and Cangjie big tables.

%package cantonese
Summary:        Cantonese input methods
Group:          System/I18n/Chinese
Provides:       ibus-table-cantonese = %{version}-%{release}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-cantonese < 1.3
%{ibus_table_requires}

%description cantonese
Cantonese input methods, including:
Cantonese, Hong-Kong version of Cantonese.

%package jyutping
Summary:        Jyutping input method
Group:          System/I18n/Chinese
Provides:       ibus-table-jyutping = %{version}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-jyutping <= 1.2.0.20090824
%{ibus_table_requires}

%description jyutping
ibus-table-jyutping provides the Jyutping input method on IBus Table under
the IBus framework.

%package easy
Summary:        The so-called "easy" input method for Chinese
Group:          System/I18n/Chinese
Provides:       ibus-table-easy = %{version}-%{release}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-easy < 1.3
%{ibus_table_requires}

%description easy
Easy phrase-wise input method.

%package erbi
Summary:        Erbi input method
Group:          System/I18n/Chinese
Provides:       ibus-table-erbi = %{version}-%{release}
Obsoletes:      ibus-table-erbi < 1.3
%{ibus_table_requires}
Provides:       locale(ibus:zh_CN)

%description erbi
Erbi input methods. Includes:
Super Erbi (as erbi)
and  Erbi Qin-Song (erbi-qs)

%package quick
Summary:        The so-called "Quick-to-learn" input methods for Chinese
Group:          System/I18n/Chinese
Provides:       ibus-table-quick = %{version}-%{release}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-quick < 1.3
%{ibus_table_requires}

%description quick
Quick-to-learn is based on the Cangjie input method,
but only needs Cangjie's first and last word-root
to form a character.

Includes:
Quick3, Quick5 and Quick-Classic,
and Smart Cangjie 6.

%package scj
Summary:        Smart Cangjie input method
Group:          System/I18n/Chinese
Provides:       ibus-table-cangjie = %{version}-%{release}
Provides:       locale(ibus:zh_TW;zh_HK)
Obsoletes:      ibus-table-cangjie < 1.3
%{ibus_table_requires}

%description scj
Smart Cangjie is an improved Cangjie base input method
which handles Cangjie, Quick, Cantonese, Chinese punctuation,
Japanese, 3000 frequent words by Hong Kong government,
both Traditional and Simplified Chinese.

This package includes Smart Cangjie 6.

%package stroke5
Summary:        Stroke 5 input method
Group:          System/I18n/Chinese
Provides:       ibus-table-stroke5 = %{version}-%{release}
Obsoletes:      ibus-table-stroke5 < 1.3
%{ibus_table_requires}
Provides:       locale(ibus:zh_CN)

%description stroke5
Stroke 5 input method.

%package wu
Summary:        Wu pronunciation input method
Group:          System/I18n/Chinese
Provides:       ibus-table-wu = %{version}-%{release}
Obsoletes:      ibus-table-wu < 1.3
%{ibus_table_requires}
Provides:       locale(ibus:zh_CN)

%description wu
Wu pronunciation input method.
URL: http://input.foruto.com/wu/

%package wubi-haifeng
Summary:        Haifeng Wubi input method
Group:          System/I18n/Chinese
Provides:       ibus-table-wubi = %{version}-%{release}
Provides:       locale(ibus:zh_CN)
Obsoletes:      ibus-table-wubi < 1.3
%{ibus_table_requires}

%description wubi-haifeng
Haifeng Wubi input methods. Current includes:
Haifeng Wubi 86.

%package wubi-jidian
Summary:        Jidian Wubi input method
Group:          System/I18n/Chinese
Provides:       ibus-table-wubi = %{version}-%{release}
Provides:       locale(ibus:zh_CN)
Obsoletes:      ibus-table-wubi < 1.3
%{ibus_table_requires}

%description wubi-jidian
Jidian Wubi input methods. Current includes:
Wubi 86.

%package yong
Summary:        YongMa input method
Group:          System/I18n/Chinese
Provides:       ibus-table-yong = %{version}-%{release}
Obsoletes:      ibus-table-yong < 1.3
%{ibus_table_requires}
Provides:       locale(ibus:zh_CN)

%description yong
YongMa input method.

%prep
%autosetup

%build
export PYTHON=python3
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DDATA_DIR=%{_datadir} \
      -DPRJ_DOC_DIR=%{_docdir}/%{name} .
make -j1 V=1

%install
%make_install
rm -rf %{buildroot}/usr/share/doc/%{name}

%post array
%ibus_table_index_post array30
%ibus_table_index_post array30-big

%post cangjie
%ibus_table_index_post cangjie3
%ibus_table_index_post cangjie5
%ibus_table_index_post cangjie-big

%post cantonese
%ibus_table_index_post cantonese
%ibus_table_index_post cantonhk

%post jyutping
%ibus_table_index_post jyutping

%post easy
%ibus_table_index_post easy-big

%post erbi
%ibus_table_index_post erbi
%ibus_table_index_post erbi-qs

%post quick
%ibus_table_index_post quick3
%ibus_table_index_post quick5
%ibus_table_index_post quick-classic

%post scj
%ibus_table_index_post scj6

%post stroke5
%ibus_table_index_post stroke5

%post wu
%ibus_table_index_post wu

%post wubi-haifeng
%ibus_table_index_post wubi-haifeng86

%post wubi-jidian
%ibus_table_index_post wubi-jidian86

%post yong
%ibus_table_index_post yong

%files array
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/array30.*
%{_ibus_tabledir}/array30.db
%{_ibus_icondir}/array30-big.*
%{_ibus_tabledir}/array30-big.db

%files cangjie
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/cangjie3.*
%{_ibus_tabledir}/cangjie3.db
%{_ibus_icondir}/cangjie5.*
%{_ibus_tabledir}/cangjie5.db
%{_ibus_icondir}/cangjie-big.*
%{_ibus_tabledir}/cangjie-big.db

%files cantonese
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/cantonese.*
%{_ibus_tabledir}/cantonese.db
%{_ibus_icondir}/cantonhk.*
%{_ibus_tabledir}/cantonhk.db
%{_ibus_icondir}/cantonyale.*
%{_ibus_tabledir}/cantonyale.db

%files jyutping
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/jyutping.*
%{_ibus_tabledir}/jyutping.db

%files easy
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/easy-big.*
%{_ibus_tabledir}/easy-big.db

%files erbi
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/erbi.*
%{_ibus_tabledir}/erbi.db
%{_ibus_icondir}/erbi-qs.*
%{_ibus_tabledir}/erbi-qs.db

%files quick
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/quick3.*
%{_ibus_tabledir}/quick3.db
%{_ibus_icondir}/quick5.*
%{_ibus_tabledir}/quick5.db
%{_ibus_icondir}/quick-classic.*
%{_ibus_tabledir}/quick-classic.db

%files scj
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/scj6.*
%{_ibus_tabledir}/scj6.db

%files stroke5
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/stroke5.*
%{_ibus_tabledir}/stroke5.db

%files wu
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/wu.*
%{_ibus_tabledir}/wu.db

%files wubi-haifeng
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/wubi-haifeng86.*
%{_ibus_tabledir}/wubi-haifeng86.db

%files wubi-jidian
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/wubi-jidian86.*
%{_ibus_tabledir}/wubi-jidian86.db

%files yong
%license COPYING
%doc ChangeLog AUTHORS NEWS README RELEASE-NOTES.txt
%{_ibus_icondir}/yong.*
%{_ibus_tabledir}/yong.db

%changelog
* Thu Apr 13 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.8.12
  * Add appdata.xml files
  * Convert license tags to SPDX format
  * Add .svg icon files for use in appdata.xml files
* Thu Nov  3 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 1.8.9 -> 1.8.11
- Improve punctuation support in cangjie5.txt, cangjie3.txt, cangjie-big.txt, quick5.txt, quick3.txt, quick-classic.txt
- Improve punctuation support in jyutping.txt, cantonese.txt, cantonhk.txt, cantonyale.txt
- Improve “improve_jyutping.py” to allow comments in the table
- Update of jyutping.txt for Unicode 15.0.0 final release
* Mon Aug  1 2022 Gordon Leung <pirateclip@protonmail.com>
  feat: use _service files to automate fetching sources
* Wed Jul 13 2022 Gordon Leung <pirateclip@protonmail.com> - 1.8.9
  update: 1.8.8 -> 1.8.9
- Add tones to Jyutping.txt table (gh#mike-fabian/ibus-table-chinese#6)
  * Tonal markers according to
  https://github.com/rime/rime-cantonese/blob/main/README-en.md#tonal-markers
  were added:
  1   v: High level, e.g. siv → 詩; High level checked, e.g. sikv → 色
  2   x: Medium rising, e.g. six → 史
  3   q: Medium level, e.g. siq→ 試; Medium level checked, e.g. sekq → 錫
  4   vv: Low falling, e.g. sivv → 時
  5   xx: Low rising, e.g. sixx → 市
  6   qq: Low level, e.g. siqq→ 事; Low level checked, e.g. sikqq → 食
  fix: CMake warning about no source or binary directory provided
* Sat Jun 25 2022 Gordon Leung <pirateclip@protonmail.com> - 1.8.8
  update: 1.8.3 -> 1.8.8
- Move source to mike-fabian's repo as previous repo is now deprecated
  * https://github.com/definite/ibus-table-chinese/blob/master/README
- Simplify CMakeLists.txt to avoid requiring cmake-fedora
- cangjie5.txt improvement gh#mike-fabian/ibus-table-chinese#87
- quick5.txt improvement gh#mike-fabian/ibus-table-chinese#4
- Add table_extra tag gh#definite/ibus-table-chinese#18
- "Traditional Chinese only" is now the default for cangjie5 and quick5
  * gh#mike-fabian/ibus-table-chinese#2
- Build outside of source tree gh#mike-fabian/ibus-table-chinese#2
  chore: clean up specfile
* Tue Jan 12 2021 Dingzhong Chen <wsxy162@gmail.com>
- Update to official release 1.8.3
  * SUMMARY=Add Suggestion mode to wubi; fix cangjie 3 and 5; fix
    description for stroke5
  * BODHI_UPDATE_TYPE=bugfix
  * REDHAT_BUGZILLA=1099380
  * [Changes]
  - GH Pull 13 Fix description stroke5 in project.spec.in
  - GH Pull 14 Freezed cangjie 3 and 5's candidate order
  - GH Pull 15 Add SUGGESTION_MODE = TRUE to the wubi tables
- Drop Source cmake-fedora, add BuildRequires cmake-fedora-modules
* Mon Oct  5 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus-table-chinese.spec: change the copyright to use
  "SUSE LLC" according to the copyright attribution rules in the
  SUSE Open Source Policy.
* Wed Apr 15 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus-table-chinese.spec: Drop the is_opensuse macro to
  eliminate the difference between SLE-15 and openSUSE-Leap.
  (jsc#SLE-11863).
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Attempt at improving English grammar in descriptions.
* Sat Feb 23 2019 Marguerite Su <i@marguerite.su>
- update version 1.8.3~pre.1531454400.f1f6a33
  * update jyutping and cantonese tables
  * fix character frequency of 'zou'
  * add cantonyale table
  * use nicer values for symbol and status prompt
  * support pinyin mode also for stroke5 table
- Fix building error on ppc64le platform(bsc#1129142).
* Sat Feb 23 2019 Marguerite Su <i@marguerite.su>
- fix Tumbleweed build
* Tue Oct 16 2018 hillwood@opensuse.org
- Drop BuildRequires tag for python3-ibus.
* Fri Dec 15 2017 hillwood@opensuse.org
- Fix boo#939462
- Use url in source tag.
* Wed May 24 2017 qzhao@suse.com
- Add is_opensuse macro in SPEC file, limit erbi stroke5 wu yong
  Chinese table default installation in SLE.
* Mon Sep 15 2014 i@marguerite.su
- fix for factory: BuildRequires: python-ibus
* Mon Jul 28 2014 i@marguerite.su
- ibus-table-jyutping has been merged into ibus-table-chinese
  so split a new subpackage to reflect the change.
* Sun Jul 27 2014 i@marguerite.su
- fix build
- delete all local summaries and descriptions.
- remove main dummy package.
- clean spec
* Sat Jul 26 2014 hillwood@linuxfans.org
- update to 1.8.2
  * Fixed Bug 1099380 - The stroke5 table should not use
  "AUTO_SELECT = TRUE" but "AUTO_SELECT = FALSE"
  * Add summary and description translation back.
* Wed Dec 19 2012 hillwood@linuxfans.org
- update to 1.4.6
  * Table build scripts has been refactored.
  * cmake-fedora is added as submodule.
  * Fixed Bug 855250 - Change the default filtering for Quick and Cangjie by
  merging maxiaojun's repository
  * Fixed Google Issue 1405: failed to build ibus-table-chinese due to missing db files
  * Fixed Google issue 1507: Add CJKV Extension C/D support for Array30
  * Merge GitHub Pull request 3: Added the inter punct
  * Merge GitHub Pull request 4: Give Cangjie and Quick users 9 candidates per page
  * Fixed IBus Google issue 1126: An error in ChineseTableLicenseAuditing
  * Complete LICENSE tag for all of the tables.
* Wed Sep 19 2012 tiwai@suse.de
- Fix the license tags of some sub packages to GPL-3.0+ (bnc#779935)
* Sat Sep  8 2012 hillwood@linuxfans.org
- update to 1.4.0
  * Table build scripts has been refactored.
  * cmake-fedora is added as submodule.
  * Fixed Bug 855250 - Change the default filtering for Quick and Cangjie by
  merging maxiaojun's repository
  * Fixed Google Issue 1405: failed to build ibus-table-chinese due to missing
  db files
* Mon Jun 18 2012 hillwood@linuxfans.org
- update to 1.3.5
- fix some bugs
- better compatibility
- with cmake-fedora modules
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Mon Sep 26 2011 andrea.turrini@gmail.com
- Fixed typos in ibus-table-chinese.spec
* Thu Aug  4 2011 tiwai@suse.de
- Corrected the license tag to GPLv3+ (bnc#709986)
* Mon Jul 25 2011 tiwai@suse.de
- Add locale-specific provides tags for automatic installation
- Don't remove buildroot at installation, use make_install macro
* Tue Jun 14 2011 swyear@gmail.com
- This package is a compound package of Chinese input method table,
  includes these old packages in M17N project,
  The following packages should be removed in M17N:
  ibus-table-array30
  ibus-table-cangjie
  ibus-table-cantonese
  ibus-table-easy
  ibus-table-erbi
  ibus-table-quick
  ibus-table-stroke5
  ibus-table-wu
  ibus-table-wubi
  ibus-table-yong
